from enum import Enum
from ibm_watsonx_data_integration.services.datastage.models.connections.base_connection import BaseConnection
from ibm_watsonx_data_integration.services.datastage.models.enums import APACHE_KAFKA_CONNECTION
from pydantic import ConfigDict, Field
from typing import ClassVar


class SaslOauthbearer(Enum):
    SASL_OAUTH2 = "SASL_OAUTH2"


class SchemaRegistryAuthentication(Enum):
    none = "none"
    reuse_sasl_credentials = "reuse_sasl_credentials"
    user_credentials = "user_credentials"


class SchemaRegistrySecure(Enum):
    kerberos = "kerberos"
    none = "none"
    ssl = "ssl"
    reuse_ssl = "reuse_ssl"


class SchemaRegistryType(Enum):
    confluent = "confluent"
    eventstreamsconfluent = "eventstreamsconfluent"


class SecureConnection(Enum):
    kerberos = "kerberos"
    none = "None"
    SASL_OAUTHBEARER = "SASL_OAUTHBEARER"
    SASL_PLAIN = "SASL_PLAIN"
    SASL_SSL = "SASL_SSL"
    SCRAM_SHA_256 = "SCRAM-SHA-256"
    SCRAM_SHA_512 = "SCRAM-SHA-512"
    SSL = "SSL"


class ApacheKafkaConn(BaseConnection):
    model_config = ConfigDict(populate_by_name=True)

    datasource_type: ClassVar[str] = "f13bc9b7-4a46-48f4-99c3-01d943334ba7"
    asset_id: str | None = None
    proj_id: str | None = None
    name: str = Field(None, alias="name")
    ds_host: str | None = Field(None, alias="_host")
    ds_port: str | None = Field(None, alias="_port")
    cluster_access_token: str | None = Field(None, alias="cluster_access_token")
    cluster_user_name: str | None = Field(None, alias="cluster_user_name")
    defer_credentials: bool | None = Field(False, alias="defer_credentials")
    key_chain_pem: str | None = Field(None, alias="key_chain_pem")
    key_password: str | None = Field(None, alias="key_password")
    key_pem: str | None = Field(None, alias="key_pem")
    keystore_location: str | None = Field(None, alias="keystore_location")
    keystore_password: str | None = Field(None, alias="keystore_password")
    keytab: str | None = Field(None, alias="keytab")
    legacy_registry_security_conf: bool | None = Field(None, alias="legacy_registry_security_conf")
    legacy_security_conf: bool | None = Field(None, alias="legacy_security_conf")
    additional_properties: str | None = Field(None, alias="oauthbearer_advanced_settings")
    client_id: str | None = Field(None, alias="oauthbearer_client_id")
    client_secret: str | None = Field(None, alias="oauthbearer_client_secret")
    scope: str | None = Field(None, alias="oauthbearer_scope")
    server_url: str | None = Field(None, alias="oauthbearer_token_endpoint_url")
    password: str | None = Field(None, alias="password")
    registry_key_chain_pem: str | None = Field(None, alias="registry_key_chain_pem")
    registry_key_password: str | None = Field(None, alias="registry_key_password")
    registry_key_pem: str | None = Field(None, alias="registry_key_pem")
    registry_keystore_location: str | None = Field(None, alias="registry_keystore_location")
    registry_keystore_password: str | None = Field(None, alias="registry_keystore_password")
    registry_keytab: str | None = Field(None, alias="registry_keytab")
    registry_password: str | None = Field(None, alias="registry_password")
    registry_principal_name: str | None = Field(None, alias="registry_principal_name")
    registry_truststore_location: str | None = Field(None, alias="registry_truststore_location")
    registry_truststore_password: str | None = Field(None, alias="registry_truststore_password")
    registry_truststore_pem: str | None = Field(None, alias="registry_truststore_pem")
    registry_username: str | None = Field(None, alias="registry_username")
    oauth_bearer_authentication: APACHE_KAFKA_CONNECTION.SaslOauthbearer | None = Field(
        APACHE_KAFKA_CONNECTION.SaslOauthbearer.SASL_OAUTH2, alias="sasl_oauthbearer"
    )
    schema_registry_authentication: APACHE_KAFKA_CONNECTION.SchemaRegistryAuthentication | None = Field(
        APACHE_KAFKA_CONNECTION.SchemaRegistryAuthentication.none, alias="schema_registry_authentication"
    )
    schema_registry_secure: APACHE_KAFKA_CONNECTION.SchemaRegistrySecure | None = Field(
        APACHE_KAFKA_CONNECTION.SchemaRegistrySecure.none, alias="schema_registry_secure"
    )
    schema_registry_type: APACHE_KAFKA_CONNECTION.SchemaRegistryType | None = Field(
        APACHE_KAFKA_CONNECTION.SchemaRegistryType.confluent, alias="schema_registry_type"
    )
    registry_url: str | None = Field(None, alias="schema_registry_url")
    secure_connection: APACHE_KAFKA_CONNECTION.SecureConnection | None = Field(
        APACHE_KAFKA_CONNECTION.SecureConnection.none, alias="secure_connection"
    )
    kafka_server_host_name: str = Field(None, alias="server_name")
    truststore_location: str | None = Field(None, alias="truststore_location")
    truststore_password: str | None = Field(None, alias="truststore_password")
    truststore_pem: str | None = Field(None, alias="truststore_pem")
    use_schema_registry_for_message_format: bool | None = Field(False, alias="use_schema_registry")
    username: str | None = Field(None, alias="username")
    vaulted_properties: str | None = Field(None, alias="vaulted_properties")
    hidden_dummy_property1: str | None = Field(None, alias="hiddenDummyProperty1")
    hidden_dummy_property2: str | None = Field(None, alias="hiddenDummyProperty2")

    def validate(self):
        include = set()
        exclude = set()

        (
            include.add("registry_key_pem")
            if (
                (
                    (
                        (
                            self.schema_registry_secure
                            and (
                                (
                                    hasattr(self.schema_registry_secure, "value")
                                    and self.schema_registry_secure.value == "ssl"
                                )
                                or (self.schema_registry_secure == "ssl")
                            )
                        )
                    )
                )
                and (self.use_schema_registry_for_message_format)
                and (not self.defer_credentials)
            )
            else exclude.add("registry_key_pem")
        )
        (
            include.add("schema_registry_authentication")
            if (((((self.use_schema_registry_for_message_format)))) or (self.use_schema_registry_for_message_format))
            else exclude.add("schema_registry_authentication")
        )
        (
            include.add("truststore_pem")
            if (
                (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "kerberos"
                                    )
                                    or (self.secure_connection == "kerberos")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "kerberos"
                                    )
                                    or (self.secure_connection == "kerberos")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("truststore_pem")
        )
        (
            include.add("keytab")
            if (
                (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "kerberos"
                                    )
                                    or (self.secure_connection == "kerberos")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "kerberos"
                                    )
                                    or (self.secure_connection == "kerberos")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("keytab")
        )
        (
            include.add("client_secret")
            if (
                (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("client_secret")
        )
        (
            include.add("registry_keystore_location")
            if (
                (
                    (((self.legacy_registry_security_conf)))
                    and (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "ssl"
                                    )
                                    or (self.schema_registry_secure == "ssl")
                                )
                            )
                        )
                    )
                    and (((self.use_schema_registry_for_message_format)))
                )
                or (
                    (((self.legacy_registry_security_conf)))
                    and (
                        self.schema_registry_secure
                        and (
                            (
                                hasattr(self.schema_registry_secure, "value")
                                and self.schema_registry_secure.value == "ssl"
                            )
                            or (self.schema_registry_secure == "ssl")
                        )
                    )
                    and (self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("registry_keystore_location")
        )
        (
            include.add("keystore_password")
            if (
                (
                    (((self.legacy_security_conf)))
                    and (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (((self.legacy_security_conf)))
                    and (
                        self.secure_connection
                        and (
                            (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                            or (self.secure_connection == "SSL")
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("keystore_password")
        )
        (
            include.add("client_id")
            if (
                (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("client_id")
        )
        (
            include.add("password")
            if (
                (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_PLAIN"
                                    )
                                    or (self.secure_connection == "SASL_PLAIN")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    ((not self.defer_credentials))
                    and (
                        (
                            (
                                (
                                    self.secure_connection
                                    and (
                                        (
                                            hasattr(self.secure_connection, "value")
                                            and self.secure_connection.value == "SASL_PLAIN"
                                        )
                                        or (self.secure_connection == "SASL_PLAIN")
                                    )
                                )
                            )
                            or (
                                (
                                    self.secure_connection
                                    and (
                                        (
                                            hasattr(self.secure_connection, "value")
                                            and self.secure_connection.value == "SASL_SSL"
                                        )
                                        or (self.secure_connection == "SASL_SSL")
                                    )
                                )
                            )
                            or (
                                (
                                    self.secure_connection
                                    and (
                                        (
                                            hasattr(self.secure_connection, "value")
                                            and self.secure_connection.value == "SCRAM-SHA-256"
                                        )
                                        or (self.secure_connection == "SCRAM-SHA-256")
                                    )
                                )
                            )
                            or (
                                (
                                    self.secure_connection
                                    and (
                                        (
                                            hasattr(self.secure_connection, "value")
                                            and self.secure_connection.value == "SCRAM-SHA-512"
                                        )
                                        or (self.secure_connection == "SCRAM-SHA-512")
                                    )
                                )
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "SASL_SSL"
                                )
                                or (self.secure_connection == "SASL_SSL")
                            )
                        )
                    )
                )
            )
            else exclude.add("password")
        )
        (
            include.add("key_pem")
            if (
                (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("key_pem")
        )
        (
            include.add("registry_password")
            if (
                (
                    (
                        (
                            self.schema_registry_authentication
                            and (
                                (
                                    hasattr(self.schema_registry_authentication, "value")
                                    and self.schema_registry_authentication.value == "user_credentials"
                                )
                                or (self.schema_registry_authentication == "user_credentials")
                            )
                        )
                    )
                )
                and (self.use_schema_registry_for_message_format)
                and (not self.defer_credentials)
            )
            else exclude.add("registry_password")
        )
        (
            include.add("truststore_password")
            if (
                (
                    (((self.legacy_security_conf)))
                    and (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "kerberos"
                                    )
                                    or (self.secure_connection == "kerberos")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (((self.legacy_security_conf)))
                    and (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "SASL_SSL"
                                )
                                or (self.secure_connection == "SASL_SSL")
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "SCRAM-SHA-256"
                                )
                                or (self.secure_connection == "SCRAM-SHA-256")
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "SCRAM-SHA-512"
                                )
                                or (self.secure_connection == "SCRAM-SHA-512")
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                or (self.secure_connection == "SSL")
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "kerberos"
                                )
                                or (self.secure_connection == "kerberos")
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("truststore_password")
        )
        (
            include.add("registry_truststore_location")
            if (
                (
                    (((self.legacy_registry_security_conf)))
                    and (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "kerberos"
                                    )
                                    or (self.schema_registry_secure == "kerberos")
                                )
                            )
                        )
                        or (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "ssl"
                                    )
                                    or (self.schema_registry_secure == "ssl")
                                )
                            )
                        )
                    )
                    and (((self.use_schema_registry_for_message_format)))
                )
                or (
                    (((self.legacy_registry_security_conf)))
                    and (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "kerberos"
                                    )
                                    or (self.schema_registry_secure == "kerberos")
                                )
                            )
                        )
                        or (
                            self.schema_registry_secure
                            and (
                                (
                                    hasattr(self.schema_registry_secure, "value")
                                    and self.schema_registry_secure.value == "ssl"
                                )
                                or (self.schema_registry_secure == "ssl")
                            )
                        )
                    )
                    and (self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("registry_truststore_location")
        )
        (
            include.add("key_password")
            if (
                (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("key_password")
        )
        (
            include.add("registry_keytab")
            if (
                (
                    (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "kerberos"
                                    )
                                    or (self.schema_registry_secure == "kerberos")
                                )
                            )
                        )
                    )
                    and (((self.use_schema_registry_for_message_format)))
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "kerberos"
                                    )
                                    or (self.schema_registry_secure == "kerberos")
                                )
                            )
                        )
                    )
                    and (self.use_schema_registry_for_message_format)
                    and (self.use_schema_registry_for_message_format)
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("registry_keytab")
        )
        (
            include.add("registry_principal_name")
            if (
                (
                    (
                        (
                            self.schema_registry_secure
                            and (
                                (
                                    hasattr(self.schema_registry_secure, "value")
                                    and self.schema_registry_secure.value == "kerberos"
                                )
                                or (self.schema_registry_secure == "kerberos")
                            )
                        )
                    )
                )
                and (self.use_schema_registry_for_message_format)
                and (not self.defer_credentials)
            )
            else exclude.add("registry_principal_name")
        )
        (
            include.add("registry_key_chain_pem")
            if (
                (
                    (
                        (
                            self.schema_registry_secure
                            and (
                                (
                                    hasattr(self.schema_registry_secure, "value")
                                    and self.schema_registry_secure.value == "ssl"
                                )
                                or (self.schema_registry_secure == "ssl")
                            )
                        )
                    )
                )
                and (self.use_schema_registry_for_message_format)
                and (not self.defer_credentials)
            )
            else exclude.add("registry_key_chain_pem")
        )
        (
            include.add("registry_truststore_password")
            if (
                (
                    (((self.legacy_registry_security_conf)))
                    and (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "kerberos"
                                    )
                                    or (self.schema_registry_secure == "kerberos")
                                )
                            )
                        )
                        or (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "ssl"
                                    )
                                    or (self.schema_registry_secure == "ssl")
                                )
                            )
                        )
                    )
                    and (((self.use_schema_registry_for_message_format)))
                )
                or (
                    (((self.legacy_registry_security_conf)))
                    and (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "kerberos"
                                    )
                                    or (self.schema_registry_secure == "kerberos")
                                )
                            )
                        )
                        or (
                            self.schema_registry_secure
                            and (
                                (
                                    hasattr(self.schema_registry_secure, "value")
                                    and self.schema_registry_secure.value == "ssl"
                                )
                                or (self.schema_registry_secure == "ssl")
                            )
                        )
                    )
                    and (self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("registry_truststore_password")
        )
        (
            include.add("registry_keystore_password")
            if (
                (
                    (((self.legacy_registry_security_conf)))
                    and (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "ssl"
                                    )
                                    or (self.schema_registry_secure == "ssl")
                                )
                            )
                        )
                    )
                    and (((self.use_schema_registry_for_message_format)))
                )
                or (
                    (((self.legacy_registry_security_conf)))
                    and (
                        self.schema_registry_secure
                        and (
                            (
                                hasattr(self.schema_registry_secure, "value")
                                and self.schema_registry_secure.value == "ssl"
                            )
                            or (self.schema_registry_secure == "ssl")
                        )
                    )
                    and (self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("registry_keystore_password")
        )
        (
            include.add("server_url")
            if (
                (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("server_url")
        )
        (
            include.add("legacy_registry_security_conf")
            if (
                (
                    (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "kerberos"
                                    )
                                    or (self.schema_registry_secure == "kerberos")
                                )
                            )
                        )
                        or (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "ssl"
                                    )
                                    or (self.schema_registry_secure == "ssl")
                                )
                            )
                        )
                    )
                    and (((self.use_schema_registry_for_message_format)))
                )
                or (
                    (
                        (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "kerberos"
                                    )
                                    or (self.schema_registry_secure == "kerberos")
                                )
                            )
                        )
                        or (
                            (
                                self.schema_registry_secure
                                and (
                                    (
                                        hasattr(self.schema_registry_secure, "value")
                                        and self.schema_registry_secure.value == "ssl"
                                    )
                                    or (self.schema_registry_secure == "ssl")
                                )
                            )
                        )
                    )
                    and (self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("legacy_registry_security_conf")
        )
        (
            include.add("truststore_location")
            if (
                (
                    (((self.legacy_security_conf)))
                    and (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "kerberos"
                                    )
                                    or (self.secure_connection == "kerberos")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (((self.legacy_security_conf)))
                    and (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "SASL_SSL"
                                )
                                or (self.secure_connection == "SASL_SSL")
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "SCRAM-SHA-256"
                                )
                                or (self.secure_connection == "SCRAM-SHA-256")
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "SCRAM-SHA-512"
                                )
                                or (self.secure_connection == "SCRAM-SHA-512")
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                or (self.secure_connection == "SSL")
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "kerberos"
                                )
                                or (self.secure_connection == "kerberos")
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("truststore_location")
        )
        (
            include.add("schema_registry_type")
            if (((((self.use_schema_registry_for_message_format)))) or (self.use_schema_registry_for_message_format))
            else exclude.add("schema_registry_type")
        )
        (
            include.add("oauth_bearer_authentication")
            if (
                (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("oauth_bearer_authentication")
        )
        include.add("registry_url") if (self.use_schema_registry_for_message_format) else exclude.add("registry_url")
        (
            include.add("registry_username")
            if (
                (
                    (
                        (
                            self.schema_registry_authentication
                            and (
                                (
                                    hasattr(self.schema_registry_authentication, "value")
                                    and self.schema_registry_authentication.value == "user_credentials"
                                )
                                or (self.schema_registry_authentication == "user_credentials")
                            )
                        )
                    )
                )
                and (self.use_schema_registry_for_message_format)
                and (not self.defer_credentials)
            )
            else exclude.add("registry_username")
        )
        (
            include.add("key_chain_pem")
            if (
                (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("key_chain_pem")
        )
        (
            include.add("registry_truststore_pem")
            if (
                (
                    (
                        (
                            self.schema_registry_secure
                            and (
                                (
                                    hasattr(self.schema_registry_secure, "value")
                                    and self.schema_registry_secure.value == "kerberos"
                                )
                                or (self.schema_registry_secure == "kerberos")
                            )
                        )
                    )
                    or (
                        (
                            self.schema_registry_secure
                            and (
                                (
                                    hasattr(self.schema_registry_secure, "value")
                                    and self.schema_registry_secure.value == "ssl"
                                )
                                or (self.schema_registry_secure == "ssl")
                            )
                        )
                    )
                )
                and (self.use_schema_registry_for_message_format)
                and (not self.defer_credentials)
            )
            else exclude.add("registry_truststore_pem")
        )
        (
            include.add("legacy_security_conf")
            if (
                (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "kerberos"
                                    )
                                    or (self.secure_connection == "kerberos")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_OAUTHBEARER"
                                    )
                                    or (self.secure_connection == "SASL_OAUTHBEARER")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "kerberos"
                                    )
                                    or (self.secure_connection == "kerberos")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("legacy_security_conf")
        )
        (
            include.add("schema_registry_secure")
            if (((((self.use_schema_registry_for_message_format)))) or (self.use_schema_registry_for_message_format))
            else exclude.add("schema_registry_secure")
        )
        (
            include.add("registry_key_password")
            if (
                (
                    (
                        (
                            self.schema_registry_secure
                            and (
                                (
                                    hasattr(self.schema_registry_secure, "value")
                                    and self.schema_registry_secure.value == "ssl"
                                )
                                or (self.schema_registry_secure == "ssl")
                            )
                        )
                    )
                )
                and (self.use_schema_registry_for_message_format)
                and (not self.defer_credentials)
            )
            else exclude.add("registry_key_password")
        )
        (
            include.add("additional_properties")
            if (
                (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("additional_properties")
        )
        (
            include.add("keystore_location")
            if (
                (
                    (((self.legacy_security_conf)))
                    and (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                                    or (self.secure_connection == "SSL")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (((self.legacy_security_conf)))
                    and (
                        self.secure_connection
                        and (
                            (hasattr(self.secure_connection, "value") and self.secure_connection.value == "SSL")
                            or (self.secure_connection == "SSL")
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("keystore_location")
        )
        (
            include.add("scope")
            if (
                (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    (
                        (
                            (
                                self.oauth_bearer_authentication
                                and (
                                    (
                                        hasattr(self.oauth_bearer_authentication, "value")
                                        and self.oauth_bearer_authentication.value == "SASL_OAUTH2"
                                    )
                                    or (self.oauth_bearer_authentication == "SASL_OAUTH2")
                                )
                            )
                        )
                    )
                    and (not self.defer_credentials)
                )
            )
            else exclude.add("scope")
        )
        (
            include.add("username")
            if (
                (
                    (
                        (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_PLAIN"
                                    )
                                    or (self.secure_connection == "SASL_PLAIN")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SASL_SSL"
                                    )
                                    or (self.secure_connection == "SASL_SSL")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-256"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-256")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "SCRAM-SHA-512"
                                    )
                                    or (self.secure_connection == "SCRAM-SHA-512")
                                )
                            )
                        )
                        or (
                            (
                                self.secure_connection
                                and (
                                    (
                                        hasattr(self.secure_connection, "value")
                                        and self.secure_connection.value == "kerberos"
                                    )
                                    or (self.secure_connection == "kerberos")
                                )
                            )
                        )
                    )
                    and ((not self.defer_credentials))
                )
                or (
                    ((not self.defer_credentials))
                    and (
                        (
                            (
                                (
                                    self.secure_connection
                                    and (
                                        (
                                            hasattr(self.secure_connection, "value")
                                            and self.secure_connection.value == "SASL_PLAIN"
                                        )
                                        or (self.secure_connection == "SASL_PLAIN")
                                    )
                                )
                            )
                            or (
                                (
                                    self.secure_connection
                                    and (
                                        (
                                            hasattr(self.secure_connection, "value")
                                            and self.secure_connection.value == "SASL_SSL"
                                        )
                                        or (self.secure_connection == "SASL_SSL")
                                    )
                                )
                            )
                            or (
                                (
                                    self.secure_connection
                                    and (
                                        (
                                            hasattr(self.secure_connection, "value")
                                            and self.secure_connection.value == "SCRAM-SHA-256"
                                        )
                                        or (self.secure_connection == "SCRAM-SHA-256")
                                    )
                                )
                            )
                            or (
                                (
                                    self.secure_connection
                                    and (
                                        (
                                            hasattr(self.secure_connection, "value")
                                            and self.secure_connection.value == "SCRAM-SHA-512"
                                        )
                                        or (self.secure_connection == "SCRAM-SHA-512")
                                    )
                                )
                            )
                            or (
                                (
                                    self.secure_connection
                                    and (
                                        (
                                            hasattr(self.secure_connection, "value")
                                            and self.secure_connection.value == "kerberos"
                                        )
                                        or (self.secure_connection == "kerberos")
                                    )
                                )
                            )
                        )
                        or (
                            self.secure_connection
                            and (
                                (
                                    hasattr(self.secure_connection, "value")
                                    and self.secure_connection.value == "SASL_SSL"
                                )
                                or (self.secure_connection == "SASL_SSL")
                            )
                        )
                    )
                )
            )
            else exclude.add("username")
        )
        (
            include.add("hidden_dummy_property2")
            if (self.hidden_dummy_property1)
            else exclude.add("hidden_dummy_property2")
        )
        (
            include.add("hidden_dummy_property1")
            if (self.hidden_dummy_property2)
            else exclude.add("hidden_dummy_property1")
        )
        (
            include.add("registry_truststore_password")
            if (self.hidden_dummy_property1)
            else exclude.add("registry_truststore_password")
        )
        (
            include.add("registry_keystore_password")
            if (self.hidden_dummy_property1)
            else exclude.add("registry_keystore_password")
        )
        (
            include.add("legacy_registry_security_conf")
            if (self.hidden_dummy_property1)
            else exclude.add("legacy_registry_security_conf")
        )
        include.add("truststore_location") if (self.hidden_dummy_property1) else exclude.add("truststore_location")
        include.add("keytab") if (self.hidden_dummy_property1) else exclude.add("keytab")
        (
            include.add("registry_keystore_location")
            if (self.hidden_dummy_property1)
            else exclude.add("registry_keystore_location")
        )
        include.add("keystore_password") if (self.hidden_dummy_property1) else exclude.add("keystore_password")
        include.add("legacy_security_conf") if (self.hidden_dummy_property1) else exclude.add("legacy_security_conf")
        include.add("truststore_password") if (self.hidden_dummy_property1) else exclude.add("truststore_password")
        include.add("vaulted_properties") if (self.hidden_dummy_property1) else exclude.add("vaulted_properties")
        (
            include.add("registry_truststore_location")
            if (self.hidden_dummy_property1)
            else exclude.add("registry_truststore_location")
        )
        include.add("keystore_location") if (self.hidden_dummy_property1) else exclude.add("keystore_location")
        include.add("registry_keytab") if (self.hidden_dummy_property1) else exclude.add("registry_keytab")
        (
            include.add("registry_principal_name")
            if (self.hidden_dummy_property1)
            else exclude.add("registry_principal_name")
        )

        (
            include.add("server_url")
            if (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("server_url")
        )
        (
            include.add("schema_registry_type")
            if (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            or (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            else exclude.add("schema_registry_type")
        )
        (
            include.add("schema_registry_secure")
            if (
                self.schema_registry_type
                and (
                    (hasattr(self.schema_registry_type, "value") and self.schema_registry_type.value == "confluent")
                    or (self.schema_registry_type == "confluent")
                )
            )
            and (
                self.schema_registry_type
                and (
                    (
                        hasattr(self.schema_registry_type, "value")
                        and self.schema_registry_type.value == "eventstreamsconfluent"
                    )
                    or (self.schema_registry_type == "eventstreamsconfluent")
                )
            )
            else exclude.add("schema_registry_secure")
        )
        (
            include.add("keystore_location")
            if (
                (self.legacy_security_conf and "true" in str(self.legacy_security_conf))
                and (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (self.legacy_security_conf and "true" in str(self.legacy_security_conf))
                and (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("keystore_location")
        )
        (
            include.add("key_password")
            if (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("key_password")
        )
        (
            include.add("registry_password")
            if (
                self.schema_registry_authentication
                and (
                    (
                        hasattr(self.schema_registry_authentication, "value")
                        and self.schema_registry_authentication.value
                        and "user_credentials" in str(self.schema_registry_authentication.value)
                    )
                    or ("user_credentials" in str(self.schema_registry_authentication))
                )
            )
            and (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            and (not self.defer_credentials)
            else exclude.add("registry_password")
        )
        (
            include.add("additional_properties")
            if (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("additional_properties")
        )
        (
            include.add("registry_username")
            if (
                self.schema_registry_authentication
                and (
                    (
                        hasattr(self.schema_registry_authentication, "value")
                        and self.schema_registry_authentication.value
                        and "user_credentials" in str(self.schema_registry_authentication.value)
                    )
                    or ("user_credentials" in str(self.schema_registry_authentication))
                )
            )
            and (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            and (not self.defer_credentials)
            else exclude.add("registry_username")
        )
        (
            include.add("registry_key_pem")
            if (
                self.schema_registry_secure
                and (
                    (
                        hasattr(self.schema_registry_secure, "value")
                        and self.schema_registry_secure.value
                        and "ssl" in str(self.schema_registry_secure.value)
                    )
                    or ("ssl" in str(self.schema_registry_secure))
                )
            )
            and (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            and (not self.defer_credentials)
            else exclude.add("registry_key_pem")
        )
        (
            include.add("registry_truststore_pem")
            if (
                self.schema_registry_secure
                and (
                    (
                        hasattr(self.schema_registry_secure, "value")
                        and self.schema_registry_secure.value
                        and "kerberos" in str(self.schema_registry_secure.value)
                    )
                    or ("kerberos" in str(self.schema_registry_secure))
                )
                and self.schema_registry_secure
                and (
                    (
                        hasattr(self.schema_registry_secure, "value")
                        and self.schema_registry_secure.value
                        and "ssl" in str(self.schema_registry_secure.value)
                    )
                    or ("ssl" in str(self.schema_registry_secure))
                )
            )
            and (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            and (not self.defer_credentials)
            else exclude.add("registry_truststore_pem")
        )
        (
            include.add("registry_keytab")
            if (
                (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "kerberos" in str(self.schema_registry_secure.value)
                        )
                        or ("kerberos" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "kerberos" in str(self.schema_registry_secure.value)
                        )
                        or ("kerberos" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
                and (not self.defer_credentials)
            )
            else exclude.add("registry_keytab")
        )
        (
            include.add("legacy_registry_security_conf")
            if (
                (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "kerberos" in str(self.schema_registry_secure.value)
                        )
                        or ("kerberos" in str(self.schema_registry_secure))
                    )
                    and self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            or (
                (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "kerberos" in str(self.schema_registry_secure.value)
                        )
                        or ("kerberos" in str(self.schema_registry_secure))
                    )
                    and self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("legacy_registry_security_conf")
        )
        (
            include.add("schema_registry_secure")
            if (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            or (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            else exclude.add("schema_registry_secure")
        )
        (
            include.add("client_secret")
            if (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("client_secret")
        )
        (
            include.add("key_pem")
            if (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("key_pem")
        )
        (
            include.add("key_chain_pem")
            if (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("key_chain_pem")
        )
        (
            include.add("truststore_location")
            if (
                (self.legacy_security_conf and "true" in str(self.legacy_security_conf))
                and (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (self.legacy_security_conf and "true" in str(self.legacy_security_conf))
                and (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("truststore_location")
        )
        (
            include.add("scope")
            if (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("scope")
        )
        (
            include.add("keytab")
            if (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("keytab")
        )
        (
            include.add("registry_key_password")
            if (
                self.schema_registry_secure
                and (
                    (
                        hasattr(self.schema_registry_secure, "value")
                        and self.schema_registry_secure.value
                        and "ssl" in str(self.schema_registry_secure.value)
                    )
                    or ("ssl" in str(self.schema_registry_secure))
                )
            )
            and (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            and (not self.defer_credentials)
            else exclude.add("registry_key_password")
        )
        (
            include.add("registry_truststore_location")
            if (
                (self.legacy_registry_security_conf and "true" in str(self.legacy_registry_security_conf))
                and (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "kerberos" in str(self.schema_registry_secure.value)
                        )
                        or ("kerberos" in str(self.schema_registry_secure))
                    )
                    and self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            or (
                (self.legacy_registry_security_conf and "true" in str(self.legacy_registry_security_conf))
                and (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "kerberos" in str(self.schema_registry_secure.value)
                        )
                        or ("kerberos" in str(self.schema_registry_secure))
                    )
                    and self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("registry_truststore_location")
        )
        (
            include.add("registry_keystore_password")
            if (
                (self.legacy_registry_security_conf and "true" in str(self.legacy_registry_security_conf))
                and (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            or (
                (self.legacy_registry_security_conf and "true" in str(self.legacy_registry_security_conf))
                and (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("registry_keystore_password")
        )
        (
            include.add("schema_registry_authentication")
            if (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            or (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            else exclude.add("schema_registry_authentication")
        )
        (
            include.add("registry_url")
            if (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            else exclude.add("registry_url")
        )
        (
            include.add("legacy_security_conf")
            if (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("legacy_security_conf")
        )
        (
            include.add("password")
            if (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_PLAIN" in str(self.secure_connection.value)
                        )
                        or ("SASL_PLAIN" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (not self.defer_credentials)
                and (
                    (
                        self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SASL_PLAIN" in str(self.secure_connection.value)
                            )
                            or ("SASL_PLAIN" in str(self.secure_connection))
                        )
                        or self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SASL_SSL" in str(self.secure_connection.value)
                            )
                            or ("SASL_SSL" in str(self.secure_connection))
                        )
                        or self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SCRAM-SHA-256" in str(self.secure_connection.value)
                            )
                            or ("SCRAM-SHA-256" in str(self.secure_connection))
                        )
                        or self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SCRAM-SHA-512" in str(self.secure_connection.value)
                            )
                            or ("SCRAM-SHA-512" in str(self.secure_connection))
                        )
                    )
                    or (
                        self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SASL_SSL" in str(self.secure_connection.value)
                            )
                            or ("SASL_SSL" in str(self.secure_connection))
                        )
                    )
                )
            )
            else exclude.add("password")
        )
        (
            include.add("username")
            if (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_PLAIN" in str(self.secure_connection.value)
                        )
                        or ("SASL_PLAIN" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (not self.defer_credentials)
                and (
                    (
                        self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SASL_PLAIN" in str(self.secure_connection.value)
                            )
                            or ("SASL_PLAIN" in str(self.secure_connection))
                        )
                        or self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SASL_SSL" in str(self.secure_connection.value)
                            )
                            or ("SASL_SSL" in str(self.secure_connection))
                        )
                        or self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SCRAM-SHA-256" in str(self.secure_connection.value)
                            )
                            or ("SCRAM-SHA-256" in str(self.secure_connection))
                        )
                        or self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SCRAM-SHA-512" in str(self.secure_connection.value)
                            )
                            or ("SCRAM-SHA-512" in str(self.secure_connection))
                        )
                        or self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "kerberos" in str(self.secure_connection.value)
                            )
                            or ("kerberos" in str(self.secure_connection))
                        )
                    )
                    or (
                        self.secure_connection
                        and (
                            (
                                hasattr(self.secure_connection, "value")
                                and self.secure_connection.value
                                and "SASL_SSL" in str(self.secure_connection.value)
                            )
                            or ("SASL_SSL" in str(self.secure_connection))
                        )
                    )
                )
            )
            else exclude.add("username")
        )
        (
            include.add("truststore_pem")
            if (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("truststore_pem")
        )
        (
            include.add("registry_key_chain_pem")
            if (
                self.schema_registry_secure
                and (
                    (
                        hasattr(self.schema_registry_secure, "value")
                        and self.schema_registry_secure.value
                        and "ssl" in str(self.schema_registry_secure.value)
                    )
                    or ("ssl" in str(self.schema_registry_secure))
                )
            )
            and (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            and (not self.defer_credentials)
            else exclude.add("registry_key_chain_pem")
        )
        (
            include.add("oauth_bearer_authentication")
            if (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("oauth_bearer_authentication")
        )
        (
            include.add("client_id")
            if (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (
                    self.oauth_bearer_authentication
                    and (
                        (
                            hasattr(self.oauth_bearer_authentication, "value")
                            and self.oauth_bearer_authentication.value
                            and "SASL_OAUTH2" in str(self.oauth_bearer_authentication.value)
                        )
                        or ("SASL_OAUTH2" in str(self.oauth_bearer_authentication))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("client_id")
        )
        (
            include.add("registry_keystore_location")
            if (
                (self.legacy_registry_security_conf and "true" in str(self.legacy_registry_security_conf))
                and (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            or (
                (self.legacy_registry_security_conf and "true" in str(self.legacy_registry_security_conf))
                and (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("registry_keystore_location")
        )
        (
            include.add("registry_principal_name")
            if (
                self.schema_registry_secure
                and (
                    (
                        hasattr(self.schema_registry_secure, "value")
                        and self.schema_registry_secure.value
                        and "kerberos" in str(self.schema_registry_secure.value)
                    )
                    or ("kerberos" in str(self.schema_registry_secure))
                )
            )
            and (
                self.use_schema_registry_for_message_format
                and "true" in str(self.use_schema_registry_for_message_format)
            )
            and (not self.defer_credentials)
            else exclude.add("registry_principal_name")
        )
        (
            include.add("truststore_password")
            if (
                (self.legacy_security_conf and "true" in str(self.legacy_security_conf))
                and (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (self.legacy_security_conf and "true" in str(self.legacy_security_conf))
                and (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_OAUTHBEARER" in str(self.secure_connection.value)
                        )
                        or ("SASL_OAUTHBEARER" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "kerberos" in str(self.secure_connection.value)
                        )
                        or ("kerberos" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("truststore_password")
        )
        (
            include.add("keystore_password")
            if (
                (self.legacy_security_conf and "true" in str(self.legacy_security_conf))
                and (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SASL_SSL" in str(self.secure_connection.value)
                        )
                        or ("SASL_SSL" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-256" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-256" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SCRAM-SHA-512" in str(self.secure_connection.value)
                        )
                        or ("SCRAM-SHA-512" in str(self.secure_connection))
                    )
                    and self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            or (
                (self.legacy_security_conf and "true" in str(self.legacy_security_conf))
                and (
                    self.secure_connection
                    and (
                        (
                            hasattr(self.secure_connection, "value")
                            and self.secure_connection.value
                            and "SSL" in str(self.secure_connection.value)
                        )
                        or ("SSL" in str(self.secure_connection))
                    )
                )
                and (not self.defer_credentials)
            )
            else exclude.add("keystore_password")
        )
        (
            include.add("registry_truststore_password")
            if (
                (self.legacy_registry_security_conf and "true" in str(self.legacy_registry_security_conf))
                and (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "kerberos" in str(self.schema_registry_secure.value)
                        )
                        or ("kerberos" in str(self.schema_registry_secure))
                    )
                    and self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            or (
                (self.legacy_registry_security_conf and "true" in str(self.legacy_registry_security_conf))
                and (
                    self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "kerberos" in str(self.schema_registry_secure.value)
                        )
                        or ("kerberos" in str(self.schema_registry_secure))
                    )
                    and self.schema_registry_secure
                    and (
                        (
                            hasattr(self.schema_registry_secure, "value")
                            and self.schema_registry_secure.value
                            and "ssl" in str(self.schema_registry_secure.value)
                        )
                        or ("ssl" in str(self.schema_registry_secure))
                    )
                )
                and (
                    self.use_schema_registry_for_message_format
                    and "true" in str(self.use_schema_registry_for_message_format)
                )
            )
            else exclude.add("registry_truststore_password")
        )
        (
            include.add("schema_registry_secure")
            if (
                self.schema_registry_type
                and (
                    (hasattr(self.schema_registry_type, "value") and self.schema_registry_type.value == "cloudera")
                    or (self.schema_registry_type == "cloudera")
                )
            )
            else exclude.add("schema_registry_secure")
        )
        return include, exclude

    @classmethod
    def from_dict(cls, properties):
        return cls.model_construct(**properties)



#  IBM Confidential
#  PID 5900-BAF
#  Copyright StreamSets Inc., an IBM Company 2025

"""Module containing AccountOwner Model."""

from ibm_watsonx_data_integration.common.models import BaseModel
from pydantic import ConfigDict, Field
from typing import TYPE_CHECKING, Optional

if TYPE_CHECKING:
    from ibm_watsonx_data_integration.platform import Platform


class AccountOwner(BaseModel):
    """Model representing the owner of an account.

    Attributes:
        user_name: The username of the account owner (often the email).
        email: The email address of the account owner.
        given_name: The given name of the account owner.
        family_name: The family name of the account owner.
    """

    user_name: str = Field(alias="userName", repr=True)
    email: str = Field(repr=False)
    given_name: str = Field(alias="givenName", repr=False)
    family_name: str = Field(alias="familyName", repr=False)

    model_config = ConfigDict(frozen=True)

    def __init__(self, platform: Optional["Platform"] = None, **account_owner_json: dict) -> None:
        """The __init__ of the Account Owner.

        Args:
            platform: The Platform object.
            account_owner_json: The JSON for the Account Owner.
        """
        super().__init__(**account_owner_json)
        self._platform = platform



from ibm_watsonx_data_integration.services.datastage.models.stage_names import STAGE_NAMES


def clean_stage_name(stage_name: str) -> str:
    """Convert a stage name to a form that is easily comparable."""
    return stage_name.replace(" ", "").replace("/", "").lower()


# Cached mapping of cleaned stage names to their corresponding full names
CLEAN_STAGE_NAMES = {clean_stage_name(name): name for name in STAGE_NAMES.keys()}


def string_to_stage_class(string: str):
    """Converts a string to a StageType enum. The string is stripped of whitespace and case is ignored during comparison.

    If the string is close to a valid stage type but not an exact match, a ValueError is raised with a suggestion.

    Args:
        string (str): The string representation of the stage type.

    Returns:
        StageType: The corresponding StageType enum value.
    """
    # First check for exact stage name match
    if string in STAGE_NAMES:
        return STAGE_NAMES[string]

    # Then try to clean the string and check against cleaned names
    clean_string = clean_stage_name(string)
    if clean_string in CLEAN_STAGE_NAMES:
        return STAGE_NAMES[CLEAN_STAGE_NAMES[clean_string]]

    # If no exact match, calculate Damerau-Levenshtein distance to find close matches
    scored = [
        (damerau_levenshtein(clean_string, candidate), CLEAN_STAGE_NAMES[candidate])
        for candidate in CLEAN_STAGE_NAMES.keys()
    ]
    scored.sort()

    # If the closest match is a probable typo, suggest it
    if scored and scored[0][0] <= 2:  # Allow a maximum distance of 2 for typos
        raise ValueError(f'Invalid stage type string: "{string}". Did you mean "{scored[0][1]}"?')

    raise ValueError(f"Invalid stage type string: {string}")


def is_probable_typo(s1: str, s2: str, max_ratio: float = 0.2) -> tuple[int, bool]:
    """Check if two strings are likely to be typos of each other based on the Damerau-Levenshtein distance."""
    if not s1 and not s2:
        return 0, False

    dist = damerau_levenshtein(s1, s2)
    max_len = max(len(s1), len(s2))
    ratio = dist / max_len
    return dist, (ratio <= max_ratio)


def damerau_levenshtein(s1: str, s2: str) -> int:
    """Compute the Damerau–Levenshtein distance between strings s1 and s2.
    This counts insertions, deletions, substitutions, and transposition of two adjacent characters.

    https://en.wikipedia.org/wiki/Damerau%E2%80%93Levenshtein_distance
    """
    len1, len2 = len(s1), len(s2)
    maxdist = len1 + len2

    # Create the distance matrix with extra padding for the algorithm
    d = [[0] * (len2 + 2) for _ in range(len1 + 2)]
    d[0][0] = maxdist
    for i in range(len1 + 1):
        d[i + 1][0] = maxdist
        d[i + 1][1] = i
    for j in range(len2 + 1):
        d[0][j + 1] = maxdist
        d[1][j + 1] = j

    # Track the last row each character was encountered in s1 or s2
    last_row = {ch: 0 for ch in set(s1 + s2)}

    for i in range(1, len1 + 1):
        last_match_col = 0
        for j in range(1, len2 + 1):
            i1 = last_row[s2[j - 1]]
            j1 = last_match_col
            cost = 0 if s1[i - 1] == s2[j - 1] else 1
            if cost == 0:
                last_match_col = j

            # substitution, insertion, deletion
            d[i + 1][j + 1] = min(
                d[i][j] + cost,
                d[i + 1][j] + 1,
                d[i][j + 1] + 1,
                # transposition
                d[i1][j1] + (i - i1 - 1) + 1 + (j - j1 - 1),
            )

        last_row[s1[i - 1]] = i

    return d[len1 + 1][len2 + 1]



from enum import Enum
from ibm_watsonx_data_integration.services.datastage.models.connections.base_connection import BaseConnection
from ibm_watsonx_data_integration.services.datastage.models.enums import AZUREDATALAKE_CONNECTION
from pydantic import ConfigDict, Field
from typing import ClassVar


class AuthMethod(Enum):
    client_credentials = "client_credentials"
    username_password = "username_password"


class ProxyProtocol(Enum):
    http = "http"
    https = "https"


class AzuredatalakeConn(BaseConnection):
    model_config = ConfigDict(populate_by_name=True)

    datasource_type: ClassVar[str] = "6863060d-97c4-4653-abbe-958bde533f8c"
    asset_id: str | None = None
    proj_id: str | None = None
    name: str = Field(None, alias="name")
    ds_host: str | None = Field(None, alias="_host")
    ds_port: str | None = Field(None, alias="_port")
    authentication_method: AZUREDATALAKE_CONNECTION.AuthMethod | None = Field(
        AZUREDATALAKE_CONNECTION.AuthMethod.client_credentials, alias="auth_method"
    )
    client_id: str = Field(None, alias="client_id")
    client_secret: str = Field(None, alias="client_secret")
    cluster_access_token: str | None = Field(None, alias="cluster_access_token")
    cluster_user_name: str | None = Field(None, alias="cluster_user_name")
    defer_credentials: bool | None = Field(False, alias="defer_credentials")
    no_proxy: str | None = Field(None, alias="no_proxy")
    password: str = Field(None, alias="password")
    proxy: bool | None = Field(False, alias="proxy")
    proxy_host: str = Field(None, alias="proxy_host")
    proxy_port: int = Field(None, alias="proxy_port")
    proxy_protocol: AZUREDATALAKE_CONNECTION.ProxyProtocol | None = Field(None, alias="proxy_protocol")
    encrypted_proxy_communication: bool | None = Field(None, alias="proxy_secured")
    ssl_certificate: str | None = Field(None, alias="ssl_certificate")
    tenant_id: str = Field(None, alias="tenant_id")
    url: str = Field(None, alias="url")
    use_home_as_root: bool | None = Field(True, alias="use_home_as_root")
    username: str = Field(None, alias="username")
    vaulted_properties: str | None = Field(None, alias="vaulted_properties")
    endpoint: str | None = Field(None, alias="endpoint")
    ssl_certificate_file: str | None = Field(None, alias="ssl_certificate_file")
    hidden_dummy_property1: str | None = Field(None, alias="hiddenDummyProperty1")
    hidden_dummy_property2: str | None = Field(None, alias="hiddenDummyProperty2")

    def validate(self):
        include = set()
        exclude = set()

        (
            include.add("tenant_id")
            if (((not self.defer_credentials)) and (not self.endpoint))
            else exclude.add("tenant_id")
        )
        include.add("ssl_certificate") if (not self.ssl_certificate_file) else exclude.add("ssl_certificate")
        include.add("proxy_port") if (self.proxy) else exclude.add("proxy_port")
        (
            include.add("encrypted_proxy_communication")
            if (
                ((self.proxy))
                and (
                    self.proxy_protocol
                    and (
                        (hasattr(self.proxy_protocol, "value") and self.proxy_protocol.value == "http")
                        or (self.proxy_protocol == "http")
                    )
                )
            )
            else exclude.add("encrypted_proxy_communication")
        )
        include.add("no_proxy") if (self.proxy) else exclude.add("no_proxy")
        include.add("proxy_protocol") if (self.proxy) else exclude.add("proxy_protocol")
        include.add("client_id") if (not self.defer_credentials) else exclude.add("client_id")
        include.add("url") if (not self.endpoint) else exclude.add("url")
        (
            include.add("password")
            if (
                ((not self.defer_credentials))
                and (
                    self.authentication_method
                    and (
                        (
                            hasattr(self.authentication_method, "value")
                            and self.authentication_method.value == "username_password"
                        )
                        or (self.authentication_method == "username_password")
                    )
                )
            )
            else exclude.add("password")
        )
        include.add("proxy_host") if (self.proxy) else exclude.add("proxy_host")
        (
            include.add("client_secret")
            if (
                ((not self.defer_credentials))
                and (
                    self.authentication_method
                    and (
                        (
                            hasattr(self.authentication_method, "value")
                            and self.authentication_method.value == "client_credentials"
                        )
                        or (self.authentication_method == "client_credentials")
                    )
                )
            )
            else exclude.add("client_secret")
        )
        (
            include.add("username")
            if (
                ((not self.defer_credentials))
                and (
                    self.authentication_method
                    and (
                        (
                            hasattr(self.authentication_method, "value")
                            and self.authentication_method.value == "username_password"
                        )
                        or (self.authentication_method == "username_password")
                    )
                )
            )
            else exclude.add("username")
        )
        (
            include.add("hidden_dummy_property2")
            if (self.hidden_dummy_property1)
            else exclude.add("hidden_dummy_property2")
        )
        (
            include.add("hidden_dummy_property1")
            if (self.hidden_dummy_property2)
            else exclude.add("hidden_dummy_property1")
        )
        include.add("endpoint") if (self.hidden_dummy_property1) else exclude.add("endpoint")
        include.add("vaulted_properties") if (self.hidden_dummy_property1) else exclude.add("vaulted_properties")
        include.add("ssl_certificate_file") if (self.hidden_dummy_property1) else exclude.add("ssl_certificate_file")

        include.add("proxy_protocol") if (self.proxy) else exclude.add("proxy_protocol")
        include.add("no_proxy") if (self.proxy) else exclude.add("no_proxy")
        include.add("url") if (not self.endpoint) else exclude.add("url")
        include.add("proxy_port") if (self.proxy) else exclude.add("proxy_port")
        include.add("client_id") if (not self.defer_credentials) else exclude.add("client_id")
        (
            include.add("password")
            if (not self.defer_credentials)
            and (
                self.authentication_method
                and (
                    (
                        hasattr(self.authentication_method, "value")
                        and self.authentication_method.value == "username_password"
                    )
                    or (self.authentication_method == "username_password")
                )
            )
            else exclude.add("password")
        )
        (
            include.add("username")
            if (not self.defer_credentials)
            and (
                self.authentication_method
                and (
                    (
                        hasattr(self.authentication_method, "value")
                        and self.authentication_method.value == "username_password"
                    )
                    or (self.authentication_method == "username_password")
                )
            )
            else exclude.add("username")
        )
        (
            include.add("encrypted_proxy_communication")
            if (self.proxy)
            and (
                self.proxy_protocol
                and (
                    (hasattr(self.proxy_protocol, "value") and self.proxy_protocol.value == "http")
                    or (self.proxy_protocol == "http")
                )
            )
            else exclude.add("encrypted_proxy_communication")
        )
        include.add("ssl_certificate") if (not self.ssl_certificate_file) else exclude.add("ssl_certificate")
        (
            include.add("client_secret")
            if (not self.defer_credentials)
            and (
                self.authentication_method
                and (
                    (
                        hasattr(self.authentication_method, "value")
                        and self.authentication_method.value == "client_credentials"
                    )
                    or (self.authentication_method == "client_credentials")
                )
            )
            else exclude.add("client_secret")
        )
        include.add("endpoint") if (not self.url) else exclude.add("endpoint")
        include.add("tenant_id") if (not self.defer_credentials) and (not self.endpoint) else exclude.add("tenant_id")
        include.add("ssl_certificate_file") if (not self.ssl_certificate) else exclude.add("ssl_certificate_file")
        include.add("proxy_host") if (self.proxy) else exclude.add("proxy_host")
        return include, exclude

    @classmethod
    def from_dict(cls, properties):
        return cls.model_construct(**properties)



from enum import Enum
from ibm_watsonx_data_integration.services.datastage.models.connections.base_connection import BaseConnection
from ibm_watsonx_data_integration.services.datastage.models.enums import ELASTICSEARCH_CONNECTION
from pydantic import ConfigDict, Field
from typing import ClassVar


class AuthMethod(Enum):
    apikey = "apikey"
    username_password = "username_password"


class ElasticsearchConn(BaseConnection):
    model_config = ConfigDict(populate_by_name=True)

    datasource_type: ClassVar[str] = "200d71ab-24a5-4b3d-85a4-a365bdd0d4cb"
    asset_id: str | None = None
    proj_id: str | None = None
    name: str = Field(None, alias="name")
    ds_host: str | None = Field(None, alias="_host")
    ds_port: str | None = Field(None, alias="_port")
    api_key: str = Field(None, alias="api_key")
    authentication_method: ELASTICSEARCH_CONNECTION.AuthMethod | None = Field(None, alias="auth_method")
    cluster_access_token: str | None = Field(None, alias="cluster_access_token")
    cluster_user_name: str | None = Field(None, alias="cluster_user_name")
    defer_credentials: bool | None = Field(False, alias="defer_credentials")
    password: str = Field(None, alias="password")
    secure_gateway_id: str | None = Field(None, alias="sg_gateway_id")
    sg_host_original: str | None = Field(None, alias="sg_host_original")
    secure_gateway_as_http_proxy: bool | None = Field(None, alias="sg_http_proxy")
    secure_gateway_security_token: str | None = Field(None, alias="sg_security_token")
    secure_gateway_service_url: str | None = Field(None, alias="sg_service_url")
    satellite_client_certificate: str | None = Field(None, alias="sl_client_cert")
    satellite_client_private_key: str | None = Field(None, alias="sl_client_private_key")
    satellite_connector_id: str | None = Field(None, alias="sl_connector_id")
    satellite_endpoint_host: str | None = Field(None, alias="sl_endpoint_host")
    satellite_endpoint_display_name: str | None = Field(None, alias="sl_endpoint_name")
    satellite_endpoint_port: int | None = Field(None, alias="sl_endpoint_port")
    sl_host_original: str | None = Field(None, alias="sl_host_original")
    satellite_as_http_proxy: bool | None = Field(None, alias="sl_http_proxy")
    satellite_location_id: str | None = Field(None, alias="sl_location_id")
    satellite_service_url: str | None = Field(None, alias="sl_service_url")
    ssl_certificate: str | None = Field(None, alias="ssl_certificate")
    url: str = Field(None, alias="url")
    use_anonymous_access: bool | None = Field(False, alias="use_anonymous_access")
    username: str = Field(None, alias="username")
    vaulted_properties: str | None = Field(None, alias="vaulted_properties")
    ssl_certificate_file: str | None = Field(None, alias="ssl_certificate_file")
    hidden_dummy_property1: str | None = Field(None, alias="hiddenDummyProperty1")
    hidden_dummy_property2: str | None = Field(None, alias="hiddenDummyProperty2")

    def validate(self):
        include = set()
        exclude = set()

        (
            include.add("password")
            if (
                (
                    ((not self.defer_credentials))
                    and ((not self.use_anonymous_access))
                    and (
                        (
                            self.authentication_method
                            and (
                                (
                                    hasattr(self.authentication_method, "value")
                                    and self.authentication_method.value == "username_password"
                                )
                                or (self.authentication_method == "username_password")
                            )
                        )
                    )
                    and ((not self.api_key))
                )
                and (((not self.defer_credentials)) and (not self.use_anonymous_access))
            )
            else exclude.add("password")
        )
        (
            include.add("satellite_connector_id")
            if (((not self.secure_gateway_id)) and (not self.satellite_location_id))
            else exclude.add("satellite_connector_id")
        )
        (
            include.add("api_key")
            if (
                ((not self.defer_credentials))
                and (not self.use_anonymous_access)
                and (
                    self.authentication_method
                    and (
                        (hasattr(self.authentication_method, "value") and self.authentication_method.value == "apikey")
                        or (self.authentication_method == "apikey")
                    )
                )
                and (not self.username)
                and (not self.password)
            )
            else exclude.add("api_key")
        )
        (
            include.add("satellite_location_id")
            if (((not self.secure_gateway_id)) and (not self.satellite_connector_id))
            else exclude.add("satellite_location_id")
        )
        (
            include.add("username")
            if (
                (
                    ((not self.defer_credentials))
                    and ((not self.use_anonymous_access))
                    and (
                        (
                            self.authentication_method
                            and (
                                (
                                    hasattr(self.authentication_method, "value")
                                    and self.authentication_method.value == "username_password"
                                )
                                or (self.authentication_method == "username_password")
                            )
                        )
                    )
                    and ((not self.api_key))
                )
                and (((not self.defer_credentials)) and (not self.use_anonymous_access))
            )
            else exclude.add("username")
        )
        include.add("use_anonymous_access") if (not self.defer_credentials) else exclude.add("use_anonymous_access")
        (
            include.add("hidden_dummy_property2")
            if (self.hidden_dummy_property1)
            else exclude.add("hidden_dummy_property2")
        )
        (
            include.add("hidden_dummy_property1")
            if (self.hidden_dummy_property2)
            else exclude.add("hidden_dummy_property1")
        )
        include.add("vaulted_properties") if (self.hidden_dummy_property1) else exclude.add("vaulted_properties")
        include.add("ssl_certificate_file") if (self.hidden_dummy_property1) else exclude.add("ssl_certificate_file")

        (
            include.add("satellite_connector_id")
            if (not self.secure_gateway_id) and (not self.satellite_location_id)
            else exclude.add("satellite_connector_id")
        )
        (
            include.add("api_key")
            if (not self.defer_credentials)
            and (not self.use_anonymous_access)
            and (
                self.authentication_method
                and (
                    (hasattr(self.authentication_method, "value") and self.authentication_method.value == "apikey")
                    or (self.authentication_method == "apikey")
                )
            )
            and (not self.username)
            and (not self.password)
            else exclude.add("api_key")
        )
        include.add("use_anonymous_access") if (not self.defer_credentials) else exclude.add("use_anonymous_access")
        (
            include.add("password")
            if (
                (not self.defer_credentials)
                and (not self.use_anonymous_access)
                and (
                    self.authentication_method
                    and (
                        (
                            hasattr(self.authentication_method, "value")
                            and self.authentication_method.value == "username_password"
                        )
                        or (self.authentication_method == "username_password")
                    )
                )
                and (not self.api_key)
            )
            and ((not self.defer_credentials) and (not self.use_anonymous_access))
            else exclude.add("password")
        )
        (
            include.add("username")
            if (
                (not self.defer_credentials)
                and (not self.use_anonymous_access)
                and (
                    self.authentication_method
                    and (
                        (
                            hasattr(self.authentication_method, "value")
                            and self.authentication_method.value == "username_password"
                        )
                        or (self.authentication_method == "username_password")
                    )
                )
                and (not self.api_key)
            )
            and ((not self.defer_credentials) and (not self.use_anonymous_access))
            else exclude.add("username")
        )
        (
            include.add("satellite_location_id")
            if (not self.secure_gateway_id) and (not self.satellite_connector_id)
            else exclude.add("satellite_location_id")
        )
        return include, exclude

    @classmethod
    def from_dict(cls, properties):
        return cls.model_construct(**properties)



import keyword
import re


class VarNamer:
    def __init__(self):
        self.name_set = VarNameSet()

    def grant_name(self, name: str):
        """
        Convert an arbitrary string into a legal Python variable name.
        """
        # replace invalid chars with underscore
        name = re.sub(r"[^0-9a-zA-Z_]", "_", name)
        # prefix underscore if it starts with a digit
        if name and name[0].isdigit():
            name = "_" + name
        # fallback for empty string or all‐underscores
        if not name or name.strip("_") == "":
            name = "var"
        # insert underscore between uppercase sequences followed by a lowercase letter: SEQOne -> seq_one
        name = re.sub(r"(?<=[A-Z])(?=[A-Z][a-z])", "_", name)
        # insert underscores between camelCase or PascalCase words: camelCase → camel_case, PascalCase → pascal_case
        name = re.sub(r"(?<=[a-z0-9])([A-Z])", r"_\1", name)
        # convert all to lowercase
        name = name.lower()
        # avoid Python keywords
        if keyword.iskeyword(name):
            name += "_"

        return self.name_set.reserve(name)


class VarNameSet:
    def __init__(self, used_names=None):
        """
        Initialize with an iterable of names that are already taken.
        """
        self._used = set(used_names or [])

    def reserve(self, prefix: str) -> str:
        """
        Reserve and return a name starting with `prefix`.
        - If `prefix` isn't taken, returns `prefix`.
        - Otherwise returns `prefix_2`, `prefix_3`, ... picking the first free one.
        """
        # if prefix itself is free, use it
        if prefix not in self._used:
            name = prefix
        else:
            # otherwise find the lowest integer suffix that’s free
            i = 2
            while f"{prefix}_{i}" in self._used:
                i += 1
            name = f"{prefix}_{i}"
        self._used.add(name)
        return name

    def is_reserved(self, name: str) -> bool:
        """Check whether a name is already reserved."""
        return name in self._used

    def release(self, name: str) -> None:
        """Optionally free up a name so it can be reused later."""
        self._used.discard(name)



# IBM Confidential
# PID 5900-BAF
# Copyright StreamSets Inc., an IBM Company 2025

"""Module containing exceptions for IBM Cloud."""

import json
from requests import Response
from requests.exceptions import HTTPError, JSONDecodeError


class IbmCloudApiException(HTTPError):
    """Exception class for errors returned by APIs."""

    def __init__(self, *args: any, **kwargs: any) -> None:
        """__init__ for the exception.

        Args:
            args: Any arguments for the error
            kwargs: Any keyword args for the error, expects a "response" object to be present.
        """
        response = kwargs.get("response")
        if isinstance(response, Response) and response.content:
            try:
                pretty_response_json = json.dumps(response.json(), indent=4)
                super().__init__(pretty_response_json, *args, **kwargs)
            except JSONDecodeError:
                super().__init__(f"<{response.status_code}> {response.reason}", *args, **kwargs)

        else:
            super().__init__(*args, **kwargs)


class IAMAuthenticationError(Exception):
    """Base class for IAM authenticator exceptions."""

    pass


class InvalidUrlError(IAMAuthenticationError):
    """Raised when the IAM URL is incorrect."""

    pass


class InvalidApiKeyError(IAMAuthenticationError):
    """Raised when the API key is invalid."""

    pass


class CloudObjectStorageNotFoundError(Exception):
    """Raised when the Cloud Object Storage resource is missing."""

    pass


class NoEnginesInstalledError(Exception):
    """Raised when no engines are installed in the environment."""

    pass


class StageNotFoundError(Exception):
    """Raised when a stage with the given label or name is not found."""

    pass


class UniqueStageNameNotFoundError(Exception):
    """Raised when a unique instance name for a stage cannot be determined."""

    pass



from enum import Enum
from ibm_watsonx_data_integration.services.datastage.models.connections.base_connection import BaseConnection
from ibm_watsonx_data_integration.services.datastage.models.enums import ORACLE_CONNECTION
from pydantic import ConfigDict, Field
from typing import ClassVar


class ConnectionMode(Enum):
    sid = "sid"
    service_name = "service_name"


class FailoverMode(Enum):
    connect = "connect"
    extended = "extended"
    select = "select"


class MetadataDiscovery(Enum):
    no_remarks = "no_remarks"
    no_remarks_or_synonyms = "no_remarks_or_synonyms"
    no_synonyms = "no_synonyms"
    remarks_and_synonyms = "remarks_and_synonyms"


class NumberType(Enum):
    double = "double"
    varchar = "varchar"


class OracleConn(BaseConnection):
    model_config = ConfigDict(populate_by_name=True)

    datasource_type: ClassVar[str] = "971223d3-093e-4957-8af9-a83181ee9dd9"
    asset_id: str | None = None
    proj_id: str | None = None
    name: str = Field(None, alias="name")
    alternate_servers: str | None = Field(None, alias="alternate_servers")
    discover_data_assets: bool | None = Field(None, alias="auto_discovery")
    cluster_access_token: str | None = Field(None, alias="cluster_access_token")
    cluster_user_name: str | None = Field(None, alias="cluster_user_name")
    conn_impersonate_user: str | None = Field(None, alias="conn_impersonate_user")
    conn_impersonate_user_password: str | None = Field(None, alias="conn_impersonate_user_password")
    connection_mode: ORACLE_CONNECTION.ConnectionMode | None = Field(None, alias="connection_mode")
    defer_credentials: bool | None = Field(False, alias="defer_credentials")
    failover_mode: ORACLE_CONNECTION.FailoverMode | None = Field(None, alias="failover_mode")
    hostname_or_ip_address: str = Field(None, alias="host")
    impersonate_user: str | None = Field(None, alias="impersonate_user")
    include_public_synonyms: bool | None = Field(False, alias="include_public_synonyms")
    kerberos_sso: bool | None = Field(None, alias="kerberos_sso")
    kerberos_sso_keytab: str | None = Field(None, alias="kerberos_sso_keytab")
    kerberos_sso_principal: str | None = Field(None, alias="kerberos_sso_principal")
    load_balancing: bool | None = Field(None, alias="load_balancing")
    metadata_discovery: ORACLE_CONNECTION.MetadataDiscovery | None = Field(
        ORACLE_CONNECTION.MetadataDiscovery.no_remarks, alias="metadata_discovery"
    )
    number_type: ORACLE_CONNECTION.NumberType | None = Field(None, alias="number_type")
    password: str = Field(None, alias="password")
    port: int = Field(None, alias="port")
    proxy: bool | None = Field(False, alias="proxy")
    proxy_host: str = Field(None, alias="proxy_host")
    proxy_password: str | None = Field(None, alias="proxy_password")
    proxy_port: int = Field(None, alias="proxy_port")
    proxy_username: str | None = Field(None, alias="proxy_user")
    retry_limit: int | None = Field(2, alias="retry_limit")
    service_name: str = Field(None, alias="service_name")
    secure_gateway_id: str | None = Field(None, alias="sg_gateway_id")
    sg_host_original: str | None = Field(None, alias="sg_host_original")
    secure_gateway_as_http_proxy: bool | None = Field(None, alias="sg_http_proxy")
    secure_gateway_security_token: str | None = Field(None, alias="sg_security_token")
    secure_gateway_service_url: str | None = Field(None, alias="sg_service_url")
    database_sid: str = Field(None, alias="sid")
    satellite_client_certificate: str | None = Field(None, alias="sl_client_cert")
    satellite_client_private_key: str | None = Field(None, alias="sl_client_private_key")
    satellite_connector_id: str | None = Field(None, alias="sl_connector_id")
    satellite_endpoint_host: str | None = Field(None, alias="sl_endpoint_host")
    satellite_endpoint_display_name: str | None = Field(None, alias="sl_endpoint_name")
    satellite_endpoint_port: int | None = Field(None, alias="sl_endpoint_port")
    sl_host_original: str | None = Field(None, alias="sl_host_original")
    satellite_as_http_proxy: bool | None = Field(None, alias="sl_http_proxy")
    satellite_location_id: str | None = Field(None, alias="sl_location_id")
    satellite_service_url: str | None = Field(None, alias="sl_service_url")
    port_is_ssl_enabled: bool | None = Field(False, alias="ssl")
    ssl_certificate: str | None = Field(None, alias="ssl_certificate")
    ssl_certificate_hostname: str | None = Field(None, alias="ssl_certificate_host")
    validate_ssl_certificate: bool | None = Field(None, alias="ssl_certificate_validation")
    use_dba_catalog_views: bool | None = Field(None, alias="use_dba_catalog_views")
    username: str = Field(None, alias="username")
    vaulted_properties: str | None = Field(None, alias="vaulted_properties")
    additional_properties: str | None = Field(None, alias="properties")
    ssl_certificate_file: str | None = Field(None, alias="ssl_certificate_file")
    hidden_dummy_property1: str | None = Field(None, alias="hiddenDummyProperty1")
    hidden_dummy_property2: str | None = Field(None, alias="hiddenDummyProperty2")

    def validate(self):
        include = set()
        exclude = set()

        (
            include.add("ssl_certificate")
            if ((((not self.ssl_certificate_file))) and (self.port_is_ssl_enabled))
            else exclude.add("ssl_certificate")
        )
        include.add("proxy_port") if (self.proxy) else exclude.add("proxy_port")
        (
            include.add("satellite_connector_id")
            if (((not self.secure_gateway_id)) and (not self.satellite_location_id))
            else exclude.add("satellite_connector_id")
        )
        (
            include.add("service_name")
            if (
                ((not self.database_sid))
                and (
                    self.connection_mode
                    and (
                        (hasattr(self.connection_mode, "value") and self.connection_mode.value == "service_name")
                        or (self.connection_mode == "service_name")
                    )
                )
            )
            else exclude.add("service_name")
        )
        (
            include.add("alternate_servers")
            if (
                ((not self.satellite_location_id))
                and (not self.satellite_connector_id)
                and (not self.secure_gateway_id)
            )
            else exclude.add("alternate_servers")
        )
        include.add("proxy_username") if (self.proxy) else exclude.add("proxy_username")
        (
            include.add("ssl_certificate_hostname")
            if (self.port_is_ssl_enabled)
            else exclude.add("ssl_certificate_hostname")
        )
        include.add("proxy_password") if (self.proxy) else exclude.add("proxy_password")
        (
            include.add("database_sid")
            if (
                ((not self.service_name))
                and (
                    self.connection_mode
                    and (
                        (hasattr(self.connection_mode, "value") and self.connection_mode.value == "sid")
                        or (self.connection_mode == "sid")
                    )
                )
            )
            else exclude.add("database_sid")
        )
        (
            include.add("password")
            if (((not self.defer_credentials)) and (((not self.defer_credentials)) and (not self.kerberos_sso)))
            else exclude.add("password")
        )
        include.add("proxy_host") if (self.proxy) else exclude.add("proxy_host")
        (
            include.add("validate_ssl_certificate")
            if (self.port_is_ssl_enabled)
            else exclude.add("validate_ssl_certificate")
        )
        (
            include.add("include_public_synonyms")
            if (
                (
                    (
                        self.metadata_discovery
                        and (
                            (
                                hasattr(self.metadata_discovery, "value")
                                and self.metadata_discovery.value == "no_remarks"
                            )
                            or (self.metadata_discovery == "no_remarks")
                        )
                    )
                )
                or (
                    self.metadata_discovery
                    and (
                        (
                            hasattr(self.metadata_discovery, "value")
                            and self.metadata_discovery.value == "remarks_and_synonyms"
                        )
                        or (self.metadata_discovery == "remarks_and_synonyms")
                    )
                )
            )
            else exclude.add("include_public_synonyms")
        )
        (
            include.add("satellite_location_id")
            if (((not self.secure_gateway_id)) and (not self.satellite_connector_id))
            else exclude.add("satellite_location_id")
        )
        (
            include.add("username")
            if (((not self.defer_credentials)) and (((not self.defer_credentials)) and (not self.kerberos_sso)))
            else exclude.add("username")
        )
        (
            include.add("hidden_dummy_property2")
            if (self.hidden_dummy_property1)
            else exclude.add("hidden_dummy_property2")
        )
        (
            include.add("hidden_dummy_property1")
            if (self.hidden_dummy_property2)
            else exclude.add("hidden_dummy_property1")
        )
        include.add("impersonate_user") if (self.hidden_dummy_property1) else exclude.add("impersonate_user")
        include.add("kerberos_sso") if (self.hidden_dummy_property1) else exclude.add("kerberos_sso")
        (
            include.add("kerberos_sso_principal")
            if (self.hidden_dummy_property1)
            else exclude.add("kerberos_sso_principal")
        )
        include.add("vaulted_properties") if (self.hidden_dummy_property1) else exclude.add("vaulted_properties")
        include.add("kerberos_sso_keytab") if (self.hidden_dummy_property1) else exclude.add("kerberos_sso_keytab")
        include.add("additional_properties") if (self.hidden_dummy_property1) else exclude.add("additional_properties")
        include.add("ssl_certificate_file") if (self.hidden_dummy_property1) else exclude.add("ssl_certificate_file")

        (
            include.add("satellite_connector_id")
            if (not self.secure_gateway_id) and (not self.satellite_location_id)
            else exclude.add("satellite_connector_id")
        )
        (
            include.add("include_public_synonyms")
            if self.metadata_discovery
            and (
                (
                    hasattr(self.metadata_discovery, "value")
                    and self.metadata_discovery.value
                    and "no_remarks" in str(self.metadata_discovery.value)
                )
                or ("no_remarks" in str(self.metadata_discovery))
            )
            or self.metadata_discovery
            and (
                (
                    hasattr(self.metadata_discovery, "value")
                    and self.metadata_discovery.value
                    and "remarks_and_synonyms" in str(self.metadata_discovery.value)
                )
                or ("remarks_and_synonyms" in str(self.metadata_discovery))
            )
            else exclude.add("include_public_synonyms")
        )
        (
            include.add("database_sid")
            if (not self.service_name)
            and (
                self.connection_mode
                and (
                    (
                        hasattr(self.connection_mode, "value")
                        and self.connection_mode.value
                        and "sid" in str(self.connection_mode.value)
                    )
                    or ("sid" in str(self.connection_mode))
                )
            )
            else exclude.add("database_sid")
        )
        include.add("proxy_port") if (self.proxy) else exclude.add("proxy_port")
        (
            include.add("password")
            if (not self.defer_credentials)
            and ((not self.defer_credentials) and (self.kerberos_sso != "true" or not self.kerberos_sso))
            else exclude.add("password")
        )
        include.add("proxy_password") if (self.proxy) else exclude.add("proxy_password")
        (
            include.add("username")
            if (not self.defer_credentials)
            and ((not self.defer_credentials) and (self.kerberos_sso != "true" or not self.kerberos_sso))
            else exclude.add("username")
        )
        (
            include.add("ssl_certificate")
            if (not self.ssl_certificate_file) and (self.port_is_ssl_enabled == "true" or self.port_is_ssl_enabled)
            else exclude.add("ssl_certificate")
        )
        (
            include.add("satellite_location_id")
            if (not self.secure_gateway_id) and (not self.satellite_connector_id)
            else exclude.add("satellite_location_id")
        )
        (
            include.add("validate_ssl_certificate")
            if (self.port_is_ssl_enabled == "true" or self.port_is_ssl_enabled)
            else exclude.add("validate_ssl_certificate")
        )
        (
            include.add("ssl_certificate_hostname")
            if (self.port_is_ssl_enabled == "true" or self.port_is_ssl_enabled)
            else exclude.add("ssl_certificate_hostname")
        )
        include.add("proxy_username") if (self.proxy) else exclude.add("proxy_username")
        (
            include.add("ssl_certificate_file")
            if (not self.ssl_certificate) and (self.port_is_ssl_enabled == "true" or self.port_is_ssl_enabled)
            else exclude.add("ssl_certificate_file")
        )
        (
            include.add("alternate_servers")
            if (not self.satellite_location_id) and (not self.satellite_connector_id) and (not self.secure_gateway_id)
            else exclude.add("alternate_servers")
        )
        (
            include.add("service_name")
            if (not self.database_sid)
            and (
                self.connection_mode
                and (
                    (
                        hasattr(self.connection_mode, "value")
                        and self.connection_mode.value
                        and "service_name" in str(self.connection_mode.value)
                    )
                    or ("service_name" in str(self.connection_mode))
                )
            )
            else exclude.add("service_name")
        )
        include.add("proxy_host") if (self.proxy) else exclude.add("proxy_host")
        return include, exclude

    @classmethod
    def from_dict(cls, properties):
        return cls.model_construct(**properties)



import ibm_watsonx_data_integration.services.datastage.models.flow_json_model as models
import ibm_watsonx_data_integration.services.datastage.models.schema.field as field
import json
from ibm_watsonx_data_integration.services.datastage.models.schema.data_definition import DataDefinition
from ibm_watsonx_data_integration.services.datastage.models.schema.field.base_field import BaseField
from typing import Literal, overload

_ODBC_TYPE_TO_FIELD_CLASS = {
    "BIGINT": field.BigInt,
    "BINARY": field.Binary,
    "BIT": field.Bit,
    "CHAR": field.Char,
    "DATE": field.Date,
    "DECIMAL": field.Decimal,
    "DOUBLE": field.Double,
    "FLOAT": field.Float,
    "INTEGER": field.Integer,
    "LONGVARBINARY": field.LongVarBinary,
    "LONGVARCHAR": field.LongVarChar,
    "NUMERIC": field.Numeric,
    "REAL": field.Real,
    "SMALLINT": field.SmallInt,
    "TIME": field.Time,
    "TIMESTAMP": field.Timestamp,
    "TINYINT": field.TinyInt,
    "UNKNOWN": field.Unknown,
    "VARBINARY": field.VarBinary,
    "VARCHAR": field.VarChar,
    "NCHAR": field.NChar,
    "LONGNVARCHAR": field.LongNVarChar,
    "NVARCHAR": field.NVarChar,
}


class Schema:
    def __init__(self, fields: list[BaseField] = None):
        self.fields = fields or []

    @property
    def configuration(self) -> models.RecordSchema:
        return models.RecordSchema(id="", fields=[f.configuration.get_field_model() for f in self.fields])

    @overload
    def add_field(self, odbc_type: Literal["BIGINT"], name: str) -> field.BigInt: ...

    @overload
    def add_field(self, odbc_type: Literal["BINARY"], name: str) -> field.Binary: ...

    @overload
    def add_field(self, odbc_type: Literal["BIT"], name: str) -> field.Bit: ...

    @overload
    def add_field(self, odbc_type: Literal["CHAR"], name: str) -> field.Char: ...

    @overload
    def add_field(self, odbc_type: Literal["DATE"], name: str) -> field.Date: ...

    @overload
    def add_field(self, odbc_type: Literal["DECIMAL"], name: str) -> field.Decimal: ...

    @overload
    def add_field(self, odbc_type: Literal["DOUBLE"], name: str) -> field.Double: ...

    @overload
    def add_field(self, odbc_type: Literal["FLOAT"], name: str) -> field.Float: ...

    @overload
    def add_field(self, odbc_type: Literal["INTEGER"], name: str) -> field.Integer: ...

    @overload
    def add_field(self, odbc_type: Literal["LONGVARBINARY"], name: str) -> field.LongVarBinary: ...

    @overload
    def add_field(self, odbc_type: Literal["LONGVARCHAR"], name: str) -> field.LongVarChar: ...

    @overload
    def add_field(self, odbc_type: Literal["NUMERIC"], name: str) -> field.Numeric: ...

    @overload
    def add_field(self, odbc_type: Literal["REAL"], name: str) -> field.Real: ...

    @overload
    def add_field(self, odbc_type: Literal["SMALLINT"], name: str) -> field.SmallInt: ...

    @overload
    def add_field(self, odbc_type: Literal["TIME"], name: str) -> field.Time: ...

    @overload
    def add_field(self, odbc_type: Literal["TIMESTAMP"], name: str) -> field.Timestamp: ...

    @overload
    def add_field(self, odbc_type: Literal["TINYINT"], name: str) -> field.TinyInt: ...

    @overload
    def add_field(self, odbc_type: Literal["UNKNOWN"], name: str) -> field.Unknown: ...

    @overload
    def add_field(self, odbc_type: Literal["VARBINARY"], name: str) -> field.VarBinary: ...

    @overload
    def add_field(self, odbc_type: Literal["VARCHAR"], name: str) -> field.VarChar: ...

    @overload
    def add_field(self, odbc_type: Literal["NCHAR"], name: str) -> field.NChar: ...

    @overload
    def add_field(self, odbc_type: Literal["LONGNVARCHAR"], name: str) -> field.LongNVarChar: ...

    @overload
    def add_field(self, odbc_type: Literal["NVARCHAR"], name: str) -> field.NVarChar: ...

    def add_field(self, odbc_type: str, name: str):
        if odbc_type.upper() in _ODBC_TYPE_TO_FIELD_CLASS:
            field_class = _ODBC_TYPE_TO_FIELD_CLASS[odbc_type.upper()]
            new_field = field_class(name=name)
            self.fields.append(new_field)
            return new_field
        else:
            raise ValueError(
                f"Unsupported field type: {odbc_type}. Supported types are: {list(_ODBC_TYPE_TO_FIELD_CLASS.keys())}"
            )

    def remove_field(self, name: str):
        new_fields = []
        for cur_field in self.fields:
            if cur_field.configuration.name != name:
                new_fields.append(cur_field)
        self.fields = new_fields
        return self

    def select_fields(self, *args: str):
        new_fields = []
        for cur_field in self.fields:
            if cur_field.configuration.name in args:
                new_fields.append(cur_field)
        return Schema(new_fields)

    def clone(self):
        new_fields = [f.clone() for f in self.fields]
        return Schema(new_fields)

    def __str__(self):
        new_fields = [str(f) for f in self.fields]
        new_fields = "[" + ",\n".join(map(str, new_fields)) + "]"
        return json.dumps(json.loads(new_fields), indent=4)

    def add_data_definition(self, data_definition: DataDefinition):
        self.fields.extend(data_definition._get_fields())
        return self



#  IBM Confidential
#  PID 5900-BAF
#  Copyright StreamSets Inc., an IBM Company 2025

"""Module containing Source class from Flow model."""

from ibm_watsonx_data_integration.codegen.sources.base_source import Source
from typing import TYPE_CHECKING
from typing_extensions import override

if TYPE_CHECKING:
    from ibm_watsonx_data_integration.cpd_models.flow_model import Flow


class FlowObjectSource(Source):
    """Loads and convert to intermediate format flow definition from ``Flow`` object."""

    def __init__(self, flow: "Flow") -> None:
        """The __init__ of the FlowObjectSource class.

        Args:
            flow: Flow object instance.
        """
        # TODO: Add validation if flow is StreamSets type.
        self._flow = flow

    @override
    def to_json(self) -> dict:
        return self._flow.model_dump()
